/*!
 * Built by ShiftSoftware
 * Copyright (c)
 */
import { Host, h } from "@stencil/core";
import cn from "../../global/lib/cn";
import expiredIcon from "./icons/expired.svg";
import pendingIcon from "./icons/pending.svg";
import cancelledIcon from "./icons/cancelled.svg";
import processedIcon from "./icons/processed.svg";
import { getVehicleInformation } from "../../global/api/vehicleInformation";
let mockData = {};
const icons = {
    expired: expiredIcon,
    pending: pendingIcon,
    processed: processedIcon,
    cancelled: cancelledIcon,
};
export class DynamicClaim {
    constructor() {
        this.pendingItemHighlighted = false;
        this.onMouseLeave = () => {
            clearTimeout(this.timeoutRef);
            this.popupClasses = '';
            this.timeoutRef = setTimeout(() => {
                this.activePopupIndex = null;
            }, 400);
        };
        this.onMouseEnter = (dynamicClaimItemHeader, idx) => {
            clearTimeout(this.timeoutRef);
            this.activePopupIndex = idx;
            this.timeoutRef = setTimeout(() => {
                const positionRef = dynamicClaimItemHeader.querySelector('.popup-position-ref');
                this.popupPositionRef = positionRef;
                this.calculatePopupPos(this.el.shadowRoot);
                this.popupClasses = 'show';
            }, 50);
        };
        this.baseUrl = undefined;
        this.isDev = false;
        this.queryString = '';
        this.isIdle = true;
        this.popupClasses = '';
        this.externalVin = null;
        this.activePopupIndex = null;
        this.vehicleInformation = undefined;
        this.errorMessage = null;
        this.isLoading = false;
        this.loadingStateChange = undefined;
        this.loadedResponse = undefined;
    }
    async componentDidLoad() {
        this.dynamicClaimBody = this.el.shadowRoot.querySelector('.dynamic-claim-body');
        this.dynamicRedeem = this.el.shadowRoot.getElementById('dynamic-redeem');
        this.dynamicClaimProgressBar = this.el.shadowRoot.querySelector('.dynamic-claim-progress-bar');
    }
    async setMockData(newMockData) {
        mockData = newMockData;
    }
    async setData(newData) {
        clearTimeout(this.networkTimeoutRef);
        if (this.abortController)
            this.abortController.abort();
        this.abortController = new AbortController();
        let scopedTimeoutRef;
        const isVinRequest = typeof newData === 'string';
        const vin = isVinRequest ? newData : newData === null || newData === void 0 ? void 0 : newData.vin;
        this.externalVin = vin;
        try {
            if (!vin || vin.trim().length === 0) {
                this.isIdle = true;
                return;
            }
            this.isLoading = true;
            this.isIdle = false;
            await new Promise(r => {
                scopedTimeoutRef = setTimeout(r, 1000);
                this.networkTimeoutRef = scopedTimeoutRef;
            });
            const vehicleResponse = isVinRequest ? await getVehicleInformation(this, { scopedTimeoutRef, vin, mockData }) : newData;
            if (this.networkTimeoutRef === scopedTimeoutRef) {
                if (!vehicleResponse)
                    throw new Error('Wrong response format');
                if (!Array.isArray(vehicleResponse.serviceItems))
                    throw new Error('No Service Available');
                this.vehicleInformation = vehicleResponse;
            }
            this.errorMessage = null;
            this.isLoading = false;
        }
        catch (error) {
            if (error && (error === null || error === void 0 ? void 0 : error.name) === 'AbortError')
                return;
            this.isLoading = false;
            this.vehicleInformation = null;
            this.errorMessage = error.message;
        }
    }
    async fetchData(requestedVin = this.externalVin) {
        await this.setData(requestedVin);
    }
    onLoadingChange(newValue) {
        if (this.loadingStateChange)
            this.loadingStateChange(newValue);
        this.setLoadingUi(newValue);
    }
    async setLoadingUi(isLoading) {
        if (!isLoading) {
            this.dynamicClaimProgressBar.style.width = '0';
            await new Promise(r => setTimeout(r, 200));
            this.updateProgressBar();
        }
    }
    updateProgressBar() {
        var _a;
        const serviceItems = ((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.serviceItems) || [];
        if (serviceItems.filter(x => x.status === 'pending').length === 0) {
            if (serviceItems.length === 0)
                this.dynamicClaimProgressBar.style.width = '0%';
            else
                this.dynamicClaimProgressBar.style.width = '100%';
            this.dynamicClaimBody.scrollTo({
                left: this.dynamicClaimBody.scrollWidth,
                behavior: 'smooth',
            });
        }
        else {
            const firstPendingItem = serviceItems.find(x => x.status === 'pending');
            const firstPendingItemIndex = serviceItems.indexOf(firstPendingItem) + 1;
            const firstPendingItemRef = this.dynamicClaimBody.getElementsByClassName('dynamic-claim-item')[firstPendingItemIndex - 1];
            this.dynamicClaimProgressBar.style.width = (firstPendingItemIndex / serviceItems.length - 1 / (serviceItems.length * 2)) * 100 + '%';
            this.dynamicClaimBody.scrollTo({
                left: firstPendingItemRef.offsetLeft - firstPendingItemRef.clientWidth * 3,
                behavior: 'smooth',
            });
        }
    }
    resetProgressBar() {
        setTimeout(() => {
            this.updateProgressBar();
        }, 100);
    }
    windowScrollListener(newValue) {
        if (newValue) {
            this.scrollListenerRef = () => this.calculatePopupPos(this.el.shadowRoot);
            window.addEventListener('scroll', this.scrollListenerRef);
            this.dynamicClaimBody.addEventListener('scroll', this.scrollListenerRef);
        }
        else {
            window.removeEventListener('scroll', this.scrollListenerRef);
            this.dynamicClaimBody.removeEventListener('scroll', this.scrollListenerRef);
        }
    }
    calculatePopupPos(root) {
        const popupPositionRef = root.querySelector('.popup-position-ref');
        let { x, y } = popupPositionRef.getBoundingClientRect();
        const popupContainer = popupPositionRef.querySelector('.popup-container');
        const { width } = popupContainer.getBoundingClientRect();
        const popupInfo = popupContainer.querySelector('.dynamic-claim-item-popup-info');
        const windowWidth = window.innerWidth; // Get the viewport's width
        popupContainer.style.top = `${y}px`;
        popupContainer.style.left = `${x - width / 2}px`;
        const offsetFromLeft = x - width / 2; // Distance from left side of the viewport
        const offsetFromRight = windowWidth - (x + width / 2); // Distance from right side of the viewport
        let movingNeeded = 0;
        let horizontalMargin = 16;
        if (offsetFromRight < horizontalMargin)
            movingNeeded = offsetFromRight - horizontalMargin;
        else if (offsetFromLeft < horizontalMargin)
            movingNeeded = Math.abs(offsetFromLeft - horizontalMargin);
        popupInfo.style.transform = `translateX(${movingNeeded}px)`;
    }
    removeLoadAnimationClass(event) {
        const component = event.target;
        component.classList.remove('load-animation');
    }
    async completeClaim() {
        var _a;
        const serviceItems = ((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.serviceItems) || [];
        const item = this.cachedClaimItem;
        const serviceDataClone = JSON.parse(JSON.stringify(serviceItems));
        const index = serviceItems.indexOf(item);
        const pendingItemsBefore = serviceDataClone.slice(0, index).filter(x => x.status === 'pending');
        serviceDataClone[index].status = 'processed';
        pendingItemsBefore.forEach(function (otherItem) {
            otherItem.status = 'cancelled';
        });
        this.pendingItemHighlighted = false;
        const vehicleDataClone = JSON.parse(JSON.stringify(this.vehicleInformation));
        vehicleDataClone.serviceItems = serviceDataClone;
        this.vehicleInformation = JSON.parse(JSON.stringify(vehicleDataClone));
    }
    claim(item) {
        var _a;
        const serviceItems = ((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.serviceItems) || [];
        const vinDataClone = JSON.parse(JSON.stringify(serviceItems));
        const index = serviceItems.indexOf(item);
        //Find other items before this item that have status 'pending'
        let pendingItemsBefore = vinDataClone.slice(0, index).filter(x => x.status === 'pending');
        this.cachedClaimItem = item;
        if (item.maximumMileage === null) {
            pendingItemsBefore = [];
        }
        this.onMouseLeave();
        this.openRedeem(item, pendingItemsBefore);
    }
    async handleRedeemScanner() {
        if (this.isDev) {
            this.dynamicRedeem.handleScanner = async (_) => {
                await new Promise(r => setTimeout(r, 500));
                this.dynamicRedeem.quite();
                this.completeClaim();
                this.dynamicRedeem.handleScanner = null;
            };
        }
        else {
            this.dynamicRedeem.handleScanner = async (code) => {
                try {
                    const vehicleInformation = this.vehicleInformation;
                    const payload = {
                        vin: vehicleInformation.vin,
                        brandIntegrationID: vehicleInformation.identifiers.brandIntegrationID,
                        invoice: code,
                        saleInformation: vehicleInformation.saleInformation,
                        serviceItem: this.dynamicRedeem.item,
                        cancelledServiceItems: this.dynamicRedeem.canceledItems,
                    };
                    const response = await fetch('/api/vehicle/swift-claim', {
                        method: 'POST',
                        headers: {
                            'Content-Type': 'application/json',
                        },
                        body: JSON.stringify(payload),
                    });
                    const data = await response.json();
                    if (!data.Success) {
                        alert(data.Message);
                        this.dynamicRedeem.quite();
                        this.dynamicRedeem.handleScanner = null;
                        return;
                    }
                    this.dynamicRedeem.quite();
                    this.completeClaim();
                    this.dynamicRedeem.handleScanner = null;
                }
                catch (error) {
                    console.error(error);
                    alert('Request failed please try again later');
                    this.dynamicRedeem.quite();
                    this.dynamicRedeem.handleScanner = null;
                }
            };
        }
    }
    openRedeem(item, oldItems) {
        var _a, _b, _c, _d, _e;
        const vehicleInformation = this.vehicleInformation;
        this.dynamicRedeem.vin = vehicleInformation === null || vehicleInformation === void 0 ? void 0 : vehicleInformation.vin;
        this.dynamicRedeem.item = item;
        this.dynamicRedeem.canceledItems = oldItems;
        if (((_a = vehicleInformation === null || vehicleInformation === void 0 ? void 0 : vehicleInformation.saleInformation) === null || _a === void 0 ? void 0 : _a.broker) !== null && ((_c = (_b = vehicleInformation === null || vehicleInformation === void 0 ? void 0 : vehicleInformation.saleInformation) === null || _b === void 0 ? void 0 : _b.broker) === null || _c === void 0 ? void 0 : _c.invoiceDate) === null)
            this.dynamicRedeem.unInvoicedByBrokerName = (_e = (_d = vehicleInformation === null || vehicleInformation === void 0 ? void 0 : vehicleInformation.saleInformation) === null || _d === void 0 ? void 0 : _d.broker) === null || _e === void 0 ? void 0 : _e.brokerName;
        else
            this.dynamicRedeem.unInvoicedByBrokerName = null;
        this.handleRedeemScanner();
    }
    createPopup(item) {
        return (h("div", { class: "popup-position-ref" }, h("div", { class: "popup-container" }, h("div", { class: cn('dynamic-claim-item-popup-info-triangle', this.popupClasses) }, h("div", { class: "dynamic-claim-item-popup-info-triangle-up" }), h("div", { class: "dynamic-claim-item-popup-info-triangle-up2" })), h("div", { class: cn('dynamic-claim-item-popup-info', this.popupClasses) }, h("table", null, h("tbody", null, h("tr", null, h("th", null, "Service Type:"), h("td", null, item.type.charAt(0).toUpperCase() + item.type.slice(1))), h("tr", null, h("th", null, "Activation Date"), h("td", null, item.activatedAt)), h("tr", null, h("th", null, "Expiry Date"), h("td", null, item.expiresAt)), h("tr", null, h("th", null, "Claimed At"), h("td", null, item.redeemDate)), h("tr", null, h("th", null, "Redeeming Dealer"), h("td", null, item.dealerName)), h("tr", null, h("th", null, "Invoice Number"), h("td", null, item.invoiceNumber)), h("tr", null, h("th", null, "WIP"), h("td", null, item.wip)), h("tr", null, h("th", null, "Menu Code"), h("td", null, item.menuCode)))), item.status === 'pending' && (h("button", { onClick: () => this.claim(item), class: "dynamic-claim-button claim-button" }, h("svg", { width: "30px", height: "30px", viewBox: "0 0 24 24", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, h("g", { "stroke-width": "0" }), h("g", { "stroke-linecap": "round", "stroke-linejoin": "round" }), h("g", null, h("circle", { cx: "12", cy: "12", r: "8", "fill-opacity": "0.24" }), h("path", { d: "M8.5 11L11.3939 13.8939C11.4525 13.9525 11.5475 13.9525 11.6061 13.8939L19.5 6", "stroke-width": "1.2" }))), h("span", null, "Claim")))))));
    }
    render() {
        var _a, _b;
        const serviceItems = ((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.serviceItems) || [];
        return (h(Host, { key: '69015f288435250b4aa463712cccce2170ee94cb' }, h("dynamic-redeem", { key: '1b304bc3204e4647d50c8272de19d946924ab612', id: "dynamic-redeem" }), h("div", { key: '6bc9e818c42a534eb72a333b25223539fc091531', class: cn('dynamic-claim-wrapper', { loading: this.isLoading, idle: this.isIdle }) }, h("div", { key: '584e4380f4eb890cc6695291858eba95d9fa1e56', class: "dynamic-claim-header" }, h("strong", { key: 'a4a2e927c9fcc1bd92a1b8a90784145f67a09490', onAnimationEnd: this.removeLoadAnimationClass, class: "dynamic-claim-header-vin load-animation" }, this.errorMessage && h("span", { key: '6166bb327b7bcd7a8f91a5f38914073862dc7d8f', style: { color: 'red' } }, this.errorMessage), !this.errorMessage && ((_b = this.vehicleInformation) === null || _b === void 0 ? void 0 : _b.vin))), h("div", { key: 'ded5c343882c16009dc2060ce09e3010aa2377cc', class: "dynamic-claim-body" }, h("div", { key: '2658f01a11bd29d449d33354a50b684272eff43a', class: "loading-lane" }, h("div", { key: '9b4136a86be3d26b2400d679e2f8906a12ad63a1', class: "dynamic-claim-loading-slider" }, h("div", { key: 'e5683ba9359f20e88b2e3e4b120bc0c9206b597c', class: "dynamic-claim-loading-slider-line" }), h("div", { key: '502bac6c4f2c7f22cc9c01bd2ee101ab5b615947', class: "dynamic-claim-loading-slider-subline dynamic-claim-inc" }), h("div", { key: 'b262ef4ae0abf92657c60a31e67a93ba2ed0b9a4', class: "dynamic-claim-loading-slider-subline dynamic-claim-dec" }))), h("div", { key: 'b46adda04f3b05c15bb101b9a26d66f47e9c3079', class: "dynamic-claim-progress-lane" }, serviceItems.map((item, idx) => {
            let statusClass = '';
            if (item.status === 'pending') {
                if (serviceItems.findIndex(i => i.status === 'pending') === idx)
                    statusClass = item.status;
            }
            else
                statusClass = item.status;
            return (h("div", { key: item.name, class: cn('dynamic-claim-item', statusClass), onMouseLeave: this.onMouseLeave }, h("div", { onAnimationEnd: this.removeLoadAnimationClass, class: "dynamic-claim-item-header load-animation", onMouseEnter: event => this.onMouseEnter(event.target, idx) }, h("img", { src: icons[item.status], alt: "status icon" }), h("span", null, item.status.charAt(0).toUpperCase() + item.status.slice(1)), this.activePopupIndex === idx && this.createPopup(item)), h("div", { onAnimationEnd: this.removeLoadAnimationClass, class: "dynamic-claim-item-circle load-animation" }), h("p", { onAnimationEnd: this.removeLoadAnimationClass, class: "dynamic-claim-item-footer load-animation" }, item.name)));
        }), h("div", { key: '395e563bc4188ffb8a320f80f4ea57bf173bf9ec', class: "dynamic-claim-progress-bar" }))))));
    }
    static get is() { return "dynamic-claim"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["dynamic-claim.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["dynamic-claim.css"]
        };
    }
    static get properties() {
        return {
            "baseUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "base-url",
                "reflect": false
            },
            "isDev": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "is-dev",
                "reflect": false,
                "defaultValue": "false"
            },
            "queryString": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "query-string",
                "reflect": false,
                "defaultValue": "''"
            },
            "loadingStateChange": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(isLoading: boolean) => void",
                    "resolved": "(isLoading: boolean) => void",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            },
            "loadedResponse": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(response: VehicleInformation) => void",
                    "resolved": "(response: VehicleInformation) => void",
                    "references": {
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            }
        };
    }
    static get states() {
        return {
            "isIdle": {},
            "popupClasses": {},
            "externalVin": {},
            "activePopupIndex": {},
            "vehicleInformation": {},
            "errorMessage": {},
            "isLoading": {}
        };
    }
    static get methods() {
        return {
            "setMockData": {
                "complexType": {
                    "signature": "(newMockData: MockJson<VehicleInformation>) => Promise<void>",
                    "parameters": [{
                            "name": "newMockData",
                            "type": "{ [key: string]: VehicleInformation; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "MockJson": {
                            "location": "import",
                            "path": "~types/components",
                            "id": "src/global/types/components.ts::MockJson"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setData": {
                "complexType": {
                    "signature": "(newData: VehicleInformation | string) => Promise<void>",
                    "parameters": [{
                            "name": "newData",
                            "type": "string | VehicleInformation",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        },
                        "ReturnType": {
                            "location": "global",
                            "id": "global::ReturnType"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fetchData": {
                "complexType": {
                    "signature": "(requestedVin?: string) => Promise<void>",
                    "parameters": [{
                            "name": "requestedVin",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "completeClaim": {
                "complexType": {
                    "signature": "() => Promise<void>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "isLoading",
                "methodName": "onLoadingChange"
            }, {
                "propName": "vehicleInformation",
                "methodName": "resetProgressBar"
            }, {
                "propName": "popupClasses",
                "methodName": "windowScrollListener"
            }];
    }
}
