/*!
 * Built by ShiftSoftware
 * Copyright (c)
 */
import { Host, h } from "@stencil/core";
import Loading from "../parts/Loading";
import { getVehicleInformation } from "../../global/api/vehicleInformation";
import Eye from "~assets/eye.svg";
import cn from "../../global/lib/cn";
import { closeImageViewer, openImageViewer } from "../../global/lib/image-expansion";
let mockData = {};
export class PaintThickness {
    constructor() {
        this.closeImageListener = (event) => {
            this.closeImage(event);
        };
        this.openImage = (target, imageSrc) => {
            openImageViewer(this, target, imageSrc);
        };
        this.closeImage = (event) => {
            closeImageViewer(this, event);
        };
        this.baseUrl = '';
        this.isDev = false;
        this.queryString = '';
        this.loadingStateChange = undefined;
        this.loadedResponse = undefined;
        this.state = 'idle';
        this.externalVin = null;
        this.errorMessage = null;
        this.expandedImage = null;
        this.vehicleInformation = undefined;
    }
    handleSettingData(response) {
        if (!response.paintThickness)
            response.paintThickness = { imageGroups: [], parts: [] };
        if (!response.paintThickness.parts || !Array.isArray(response.paintThickness.parts))
            response.paintThickness.parts = [];
        if (!response.paintThickness.imageGroups || !Array.isArray(response.paintThickness.imageGroups))
            response.paintThickness.imageGroups = [];
        this.vehicleInformation = response;
    }
    async setData(newData) {
        clearTimeout(this.networkTimeoutRef);
        if (this.abortController)
            this.abortController.abort();
        this.abortController = new AbortController();
        let scopedTimeoutRef;
        const isVinRequest = typeof newData === 'string';
        const vin = isVinRequest ? newData : newData === null || newData === void 0 ? void 0 : newData.vin;
        this.externalVin = vin;
        try {
            if (!vin || vin.trim().length === 0) {
                //this.componentHeight = '0px';
                this.state = 'idle';
                return;
            }
            if (this.state === 'data' || this.state === 'error') {
                this.state = (this.state + '-loading');
            }
            else
                this.state = 'loading';
            await new Promise(r => {
                scopedTimeoutRef = setTimeout(r, 700);
                this.networkTimeoutRef = scopedTimeoutRef;
            });
            const vehicleResponse = isVinRequest ? await getVehicleInformation(this, { scopedTimeoutRef, vin, mockData }) : newData;
            if (this.networkTimeoutRef === scopedTimeoutRef) {
                if (!vehicleResponse)
                    throw new Error('Wrong response format');
                this.handleSettingData(vehicleResponse);
            }
            this.errorMessage = null;
            this.state = 'data';
        }
        catch (error) {
            if (error && (error === null || error === void 0 ? void 0 : error.name) === 'AbortError')
                return;
            this.state = 'error';
            this.vehicleInformation = null;
            this.errorMessage = error.message;
        }
    }
    async fetchData(requestedVin = this.externalVin) {
        await this.setData(requestedVin);
    }
    //calculateHeight(componentState: string) {
    //  if (componentState.includes('loading') && this.componentHeight === '0px') {
    //    this.componentHeight = '100px';
    //  } else if (componentState !== 'idle') {
    //    setTimeout(() => {
    //      this.componentHeight = `${this.wrapperRef.clientHeight}px`;
    //    }, 50);
    //  } else {
    //    this.componentHeight = '0px';
    //  }
    //}
    async loadingListener() {
        //this.calculateHeight(newState);
        if (this.loadingStateChange)
            this.loadingStateChange(this.state.includes('loading'));
    }
    async setMockData(newMockData) {
        mockData = newMockData;
    }
    render() {
        var _a, _b;
        const { imageGroups, parts } = (this === null || this === void 0 ? void 0 : this.vehicleInformation) ? (_a = this === null || this === void 0 ? void 0 : this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.paintThickness : { imageGroups: [], parts: [] };
        return (h(Host, { key: '9a37ff8b80882903930f12750061163ed91b0f6c' }, h("div", { key: '8818049394cfd24bb9fa404f5cc01fe7b91dac7b', class: "min-h-[100px] relative transition-all duration-300 overflow-hidden" }, h("div", { key: 'f51b316ebaa44325d61e334539056fd678ae805d' }, h(Loading, { key: '1811f64aca9be9e4e6783071ebbfcd2cf98a71b9', isLoading: this.state.includes('loading') }), h("div", { key: '349cf8a3ca0f1306c1a589e74567f92423be0dd1', class: cn('transition-all duration-700', { 'scale-0': this.state.includes('loading') || this.state === 'idle', 'opacity-0': this.state.includes('loading') }) }, h("div", { key: '94c27a1c1209ed8ebbc94b8cc10efdc4cf8bfc06', class: cn('text-center pt-[4px] text-[20px]', { 'text-red-600': !!this.errorMessage }) }, (_b = this.vehicleInformation) === null || _b === void 0 ? void 0 : _b.vin), ['error', 'error-loading'].includes(this.state) && (h("div", { key: '0c553c082743239148ca5a1600362f56d71a7a3f', class: "py-[16px]" }, h("div", { key: '8d9901ed4c562e87415a82f4c518dd628b9ad943', class: " px-[16px] py-[8px] border reject-card text-[20px] rounded-[8px] w-fit mx-auto" }, this.errorMessage))), ['data', 'data-loading'].includes(this.state) && (h("div", { key: 'cab2e618e6dc110bcd32b338b3901400d835d0fe', class: "flex mt-[12px] w-full max-h-[70dvh] overflow-hidden mx-auto rounded-[4px] flex-col border border-[#d6d8dc]" }, h("div", { key: 'e40e49447bea108e25318f86bdc6074637470a09', class: "w-full h-[40px] flex shrink-0 justify-center text-[18px] items-center text-[#383c43] text-center bg-[#e1e3e5]" }, "Paint Thickeness"), h("div", { key: '96ef8ed3d5af6404ec8ae63e65cdcf5c8da08ff7', class: "h-0 overflow-auto flex-1" }, !parts.length && h("div", { key: '4672e3a4bab3dbc12dc4875f3b1b0cb187f0819c', class: "h-[50px] px-[30px] flex items-center justify-center text-[18px]" }, "No parts are available."), !!parts.length && (h("table", { key: 'c0f307e3360644f306c8a71eb743452bc21118bc', class: "w-full overflow-auto relative border-collapse" }, h("thead", { key: '74f2e17695542cb70b18561766ab64c098ede57c', class: "top-0 font-bold sticky bg-white" }, h("tr", { key: 'ba1aa96a1574085c4ed42ccb1afca5a9715fc638' }, ['Part', 'Left', 'Right'].map(title => (h("th", { key: title, class: "px-[15px] min-w-[100px] py-[15px] text-center whitespace-nowrap border-b border-[#d6d8dc]" }, title))))), h("tbody", { key: '79cc2054d7f29e552ef5c1cda62820f7204b6578' }, parts.map((part, idx) => (h("tr", { class: "transition-colors duration-100 hover:bg-slate-100", key: part.part }, ['part', 'left', 'right'].map(key => (h("td", { key: part.part + key, class: cn('px-[10px] py-[20px] text-center whitespace-nowrap border-b border-[#d6d8dc]', {
                '!border-none': idx === parts.length - 1,
            }) }, part[key] || '...')))))))))))), ['data', 'data-loading'].includes(this.state) && (h("div", { key: 'a42fd7083cecba578d367524d0d6dff8eac34ba0' }, !imageGroups.length && h("div", { key: 'ae5765160cef9769877d137a5ff926fb29eefb41', class: "h-[40px] px-[30px] flex text-red-500 items-center justify-center text-[18px]" }, "No image groups are available."), !!imageGroups.length && (h("div", { key: '1cf3267f6a2798b750988ec803a6dc864d434a83', class: "py-[16px] gap-[16px] justify-center flex flex-wrap px-[24px] w-full" }, imageGroups.map(imageGroup => (h("div", { class: "shrink-0 rounded-lg shadow-sm border overflow-hidden flex flex-col", key: imageGroup.name }, h("h1", { class: "text-center border-b bg-slate-200 font-semibold p-[6px]" }, imageGroup.name), h("div", { class: "flex p-[12px] gap-[8px]" }, imageGroup.images.map(image => (h("div", { class: "flex gap-[8px]", key: image }, h("button", { onClick: ({ target }) => this.openImage(target, image), class: "shrink-0 relative ring-0 outline-none w-fit mx-auto [&_img]:hover:shadow-lg [&_div]:hover:!opacity-100 cursor-pointer" }, h("div", { class: "absolute flex-col justify-center gap-[4px] size-full flex items-center pointer-events-none hover:opacity-100 rounded-lg opacity-0 bg-black/40 transition-all duration-300" }, h("img", { src: Eye }), h("span", { class: "text-white" }, "Expand")), h("img", { class: "w-auto h-[150px] cursor-pointer shadow-sm rounded-lg transition-all duration-300", src: image }))))))))), h("div", { key: '8d609b567dfc7229f168ab4d2232d161a2b613dd', onClick: () => this.closeImage(), style: { backdropFilter: this.expandedImage ? 'blur(3px)' : 'blur(0px)' }, class: cn('pointer-events-none w-[100dvw] h-[100dvh] fixed top-0 z-10 left-0 opacity-0 bg-black/40 transition-all duration-400', {
                'pointer-events-auto opacity-100 delay-200': this.expandedImage,
            }) }, h("button", { key: 'c37ca70c557479eba143dae1f8a971463b7f2411', class: "flex flex-col mt-[16px] items-center justify-center size-12 float-right mr-[16px]", onClick: () => this.closeImage() }, h("div", { key: '7a0b3baa108e5746d6001ed7af286919c5b07bb6', class: "h-1 w-12 rounded-full rotate-45 absolute bg-white" }), h("div", { key: 'be1d55cf425a6cd64e1583426d9c889b36260f79', class: "h-1 w-12 rounded-full -rotate-45 absolute bg-white" }))), h("img", { key: '1dee0a3f8e7f4a0a7d3dfe4c3e58d89f7977ef15', alt: "", id: "expanded-image", class: "fixed opacity-0 z-40 transition-all rounded-lg" }))))))))));
    }
    static get is() { return "paint-thickness"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["paint-thickness.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["paint-thickness.css"]
        };
    }
    static get properties() {
        return {
            "baseUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "base-url",
                "reflect": false,
                "defaultValue": "''"
            },
            "isDev": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "is-dev",
                "reflect": false,
                "defaultValue": "false"
            },
            "queryString": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "query-string",
                "reflect": false,
                "defaultValue": "''"
            },
            "loadingStateChange": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(isLoading: boolean) => void",
                    "resolved": "(isLoading: boolean) => void",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            },
            "loadedResponse": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(response: VehicleInformation) => void",
                    "resolved": "(response: VehicleInformation) => void",
                    "references": {
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            }
        };
    }
    static get states() {
        return {
            "state": {},
            "externalVin": {},
            "errorMessage": {},
            "expandedImage": {},
            "vehicleInformation": {}
        };
    }
    static get methods() {
        return {
            "setData": {
                "complexType": {
                    "signature": "(newData: VehicleInformation | string) => Promise<void>",
                    "parameters": [{
                            "name": "newData",
                            "type": "string | VehicleInformation",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        },
                        "ReturnType": {
                            "location": "global",
                            "id": "global::ReturnType"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fetchData": {
                "complexType": {
                    "signature": "(requestedVin?: string) => Promise<void>",
                    "parameters": [{
                            "name": "requestedVin",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setMockData": {
                "complexType": {
                    "signature": "(newMockData: MockJson<VehicleInformation>) => Promise<void>",
                    "parameters": [{
                            "name": "newMockData",
                            "type": "{ [key: string]: VehicleInformation; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "MockJson": {
                            "location": "import",
                            "path": "~types/components",
                            "id": "src/global/types/components.ts::MockJson"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "state",
                "methodName": "loadingListener"
            }];
    }
}
