/*!
 * Built by ShiftSoftware
 * Copyright (c)
 */
import { Host, h } from "@stencil/core";
import Loading from "../parts/Loading";
import cn from "../../global/lib/cn";
import { getVehicleInformation } from "../../global/api/vehicleInformation";
let mockData = {};
export class ServiceHistory {
    constructor() {
        this.baseUrl = '';
        this.isDev = false;
        this.queryString = '';
        this.loadingStateChange = undefined;
        this.loadedResponse = undefined;
        this.state = 'idle';
        this.externalVin = null;
        this.errorMessage = null;
        this.vehicleInformation = undefined;
    }
    handleSettingData(response) {
        if (response.serviceHistory === null)
            response.serviceHistory = [];
        this.vehicleInformation = response;
    }
    async setData(newData) {
        clearTimeout(this.networkTimeoutRef);
        if (this.abortController)
            this.abortController.abort();
        this.abortController = new AbortController();
        let scopedTimeoutRef;
        const isVinRequest = typeof newData === 'string';
        const vin = isVinRequest ? newData : newData === null || newData === void 0 ? void 0 : newData.vin;
        this.externalVin = vin;
        try {
            if (!vin || vin.trim().length === 0) {
                //this.componentHeight = '0px';
                this.state = 'idle';
                return;
            }
            if (this.state === 'data' || this.state === 'error') {
                this.state = (this.state + '-loading');
            }
            else
                this.state = 'loading';
            await new Promise(r => {
                scopedTimeoutRef = setTimeout(r, 700);
                this.networkTimeoutRef = scopedTimeoutRef;
            });
            const vehicleResponse = isVinRequest ? await getVehicleInformation(this, { scopedTimeoutRef, vin, mockData }) : newData;
            if (this.networkTimeoutRef === scopedTimeoutRef) {
                if (!vehicleResponse)
                    throw new Error('Wrong response format');
                this.handleSettingData(vehicleResponse);
            }
            this.errorMessage = null;
            this.state = 'data';
        }
        catch (error) {
            if (error && (error === null || error === void 0 ? void 0 : error.name) === 'AbortError')
                return;
            this.state = 'error';
            this.vehicleInformation = null;
            this.errorMessage = error.message;
        }
    }
    async fetchData(requestedVin = this.externalVin) {
        await this.setData(requestedVin);
    }
    //calculateHeight(componentState: string) {
    //  if (componentState.includes('loading') && this.componentHeight === '0px') {
    //    this.componentHeight = '100px';
    //  } else if (componentState !== 'idle') {
    //    setTimeout(() => {
    //      this.componentHeight = `${this.wrapperRef.clientHeight}px`;
    //    }, 50);
    //  } else {
    //    this.componentHeight = '0px';
    //  }
    //}
    async loadingListener() {
        //this.calculateHeight(newState);
        if (this.loadingStateChange)
            this.loadingStateChange(this.state.includes('loading'));
    }
    async setMockData(newMockData) {
        mockData = newMockData;
    }
    render() {
        var _a, _b, _c, _d;
        return (h(Host, { key: '555a348cb6732d8f8fc29c38599b9071c5e1f0f2' }, h("div", { key: '906bb7939824fa13d12f5a1904f3eb8a30fa7a67', class: "min-h-[100px] relative transition-all duration-300 overflow-hidden" }, h("div", { key: '00b12e3f14ec2936e024f5c22281ab7b5de1ef0d' }, h(Loading, { key: '22124886ed44093708e860d5e9359ccf3c1d6a87', isLoading: this.state.includes('loading') }), h("div", { key: 'ca0140dee8ecf498071d6cfaaa044fc2eb20e75d', class: cn('transition-all duration-700', { 'scale-0': this.state.includes('loading') || this.state === 'idle', 'opacity-0': this.state.includes('loading') }) }, h("div", { key: 'd13e6148a7bbc44c8f54358d6fb5c2d7487e9b26', class: cn('text-center pt-[4px] text-[20px]', { 'text-red-600': !!this.errorMessage }) }, (_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.vin), ['error', 'error-loading'].includes(this.state) && (h("div", { key: '52ed9363b91499f404d9eef3e4d375c36ef3ab21', class: "py-[16px]" }, h("div", { key: 'ca8590014470093e33cd490162b423b63cb7529d', class: " px-[16px] py-[8px] border reject-card text-[20px] rounded-[8px] w-fit mx-auto" }, this.errorMessage))), ['data', 'data-loading'].includes(this.state) && (h("div", { key: 'f7bfb9172760c271565afd87ad9e608ad6f00fa5', class: "flex mt-[12px] max-h-[70dvh] overflow-hidden rounded-[4px] flex-col border border-[#d6d8dc]" }, h("div", { key: '45f76af5de889733f5a736fc0c5a16ad9f7ff02b', class: "w-full h-[40px] flex shrink-0 justify-center text-[18px] items-center text-[#383c43] text-center bg-[#e1e3e5]" }, "Service History"), h("div", { key: 'e2b6e0dc79b7c973922a0b765755f0a539c13149', class: "h-0 overflow-auto flex-1" }, !((_b = this.vehicleInformation) === null || _b === void 0 ? void 0 : _b.serviceHistory.length) && h("div", { key: 'de0b9ff581b4d12cb725f0cd89a1016f1932c779', class: "h-[80px] flex items-center justify-center text-[18px]" }, "No data is available."), !!((_c = this.vehicleInformation) === null || _c === void 0 ? void 0 : _c.serviceHistory.length) && (h("table", { key: '7606eb53095c756589d82a6f1872674603ea2311', class: "w-full overflow-auto relative border-collapse" }, h("thead", { key: '2ac057a54aa6d3cb8891473b301fa837d5de59cd', class: "top-0 font-bold sticky bg-white" }, h("tr", { key: 'ae1f415d6f904c092fea61c0645536b8bc09ede5' }, ['Branch', 'Dealer', 'Invoice No.', 'Date', 'Service Type', 'Odometer'].map(title => (h("th", { key: title, class: "px-[10px] py-[20px] text-center whitespace-nowrap border-b border-[#d6d8dc]" }, title))))), h("tbody", { key: '24fc8f0f4e886a8aed23f0cc2d776b1343d4833a' }, (_d = this.vehicleInformation) === null || _d === void 0 ? void 0 : _d.serviceHistory.map((service, idx) => (h("tr", { class: "transition-colors duration-100 hover:bg-slate-100", key: service.invoiceNumber }, ['branchName', 'companyName', 'invoiceNumber', 'serviceDate', 'serviceType', 'mileage'].map(serviceType => {
            var _a;
            return (h("td", { key: service.invoiceNumber + serviceType, class: cn('px-[10px] py-[20px] text-center whitespace-nowrap border-b border-[#d6d8dc]', {
                    '!border-none': idx === ((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.serviceHistory.length) - 1,
                }) }, service[serviceType] || '...'));
        })))))))))))))));
    }
    static get is() { return "service-history"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["service-history.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["service-history.css"]
        };
    }
    static get properties() {
        return {
            "baseUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "base-url",
                "reflect": false,
                "defaultValue": "''"
            },
            "isDev": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "is-dev",
                "reflect": false,
                "defaultValue": "false"
            },
            "queryString": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "query-string",
                "reflect": false,
                "defaultValue": "''"
            },
            "loadingStateChange": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(isLoading: boolean) => void",
                    "resolved": "(isLoading: boolean) => void",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            },
            "loadedResponse": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(response: VehicleInformation) => void",
                    "resolved": "(response: VehicleInformation) => void",
                    "references": {
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            }
        };
    }
    static get states() {
        return {
            "state": {},
            "externalVin": {},
            "errorMessage": {},
            "vehicleInformation": {}
        };
    }
    static get methods() {
        return {
            "setData": {
                "complexType": {
                    "signature": "(newData: VehicleInformation | string) => Promise<void>",
                    "parameters": [{
                            "name": "newData",
                            "type": "string | VehicleInformation",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        },
                        "ReturnType": {
                            "location": "global",
                            "id": "global::ReturnType"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fetchData": {
                "complexType": {
                    "signature": "(requestedVin?: string) => Promise<void>",
                    "parameters": [{
                            "name": "requestedVin",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setMockData": {
                "complexType": {
                    "signature": "(newMockData: MockJson<VehicleInformation>) => Promise<void>",
                    "parameters": [{
                            "name": "newMockData",
                            "type": "{ [key: string]: VehicleInformation; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "MockJson": {
                            "location": "import",
                            "path": "~types/components",
                            "id": "src/global/types/components.ts::MockJson"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "state",
                "methodName": "loadingListener"
            }];
    }
}
