/*!
 * Built by ShiftSoftware
 * Copyright (c)
 */
import { Host, h } from "@stencil/core";
import { getVehicleInformation } from "../../global/api/vehicleInformation";
import cn from "../../global/lib/cn";
import Loading from "../parts/Loading";
import Eye from "~assets/eye.svg";
import { closeImageViewer, openImageViewer } from "../../global/lib/image-expansion";
let mockData = {};
export class VehicleAccessories {
    constructor() {
        this.closeImageListener = (event) => {
            this.closeImage(event);
        };
        this.openImage = (target, imageSrc) => {
            openImageViewer(this, target, imageSrc);
        };
        this.closeImage = (event) => {
            closeImageViewer(this, event);
        };
        this.baseUrl = '';
        this.isDev = false;
        this.queryString = '';
        this.loadingStateChange = undefined;
        this.loadedResponse = undefined;
        this.state = 'idle';
        this.externalVin = null;
        this.errorMessage = null;
        this.expandedImage = null;
        this.vehicleInformation = undefined;
    }
    handleSettingData(response) {
        if (!response.accessories || !Array.isArray(response.accessories))
            response.accessories = [];
        this.vehicleInformation = response;
    }
    async setData(newData) {
        clearTimeout(this.networkTimeoutRef);
        if (this.abortController)
            this.abortController.abort();
        this.abortController = new AbortController();
        let scopedTimeoutRef;
        const isVinRequest = typeof newData === 'string';
        const vin = isVinRequest ? newData : newData === null || newData === void 0 ? void 0 : newData.vin;
        this.externalVin = vin;
        try {
            if (!vin || vin.trim().length === 0) {
                //this.componentHeight = '0px';
                this.state = 'idle';
                return;
            }
            if (this.state === 'data' || this.state === 'error') {
                this.state = (this.state + '-loading');
            }
            else
                this.state = 'loading';
            await new Promise(r => {
                scopedTimeoutRef = setTimeout(r, 700);
                this.networkTimeoutRef = scopedTimeoutRef;
            });
            const vehicleResponse = isVinRequest ? await getVehicleInformation(this, { scopedTimeoutRef, vin, mockData }) : newData;
            if (this.networkTimeoutRef === scopedTimeoutRef) {
                if (!vehicleResponse)
                    throw new Error('Wrong response format');
                this.handleSettingData(vehicleResponse);
            }
            this.errorMessage = null;
            this.state = 'data';
        }
        catch (error) {
            if (error && (error === null || error === void 0 ? void 0 : error.name) === 'AbortError')
                return;
            this.state = 'error';
            this.vehicleInformation = null;
            this.errorMessage = error.message;
        }
    }
    async fetchData(requestedVin = this.externalVin) {
        await this.setData(requestedVin);
    }
    //calculateHeight(componentState: string) {
    //  if (componentState.includes('loading') && this.componentHeight === '0px') {
    //    this.componentHeight = '100px';
    //  } else if (componentState !== 'idle') {
    //    setTimeout(() => {
    //      this.componentHeight = `${this.wrapperRef.clientHeight}px`;
    //    }, 50);
    //  } else {
    //    this.componentHeight = '0px';
    //  }
    //}
    async loadingListener() {
        //this.calculateHeight(newState);
        if (this.loadingStateChange)
            this.loadingStateChange(this.state.includes('loading'));
    }
    async setMockData(newMockData) {
        mockData = newMockData;
    }
    render() {
        var _a, _b;
        const accessories = (this === null || this === void 0 ? void 0 : this.vehicleInformation) ? (_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.accessories : [];
        return (h(Host, { key: 'b10fadf410ded644e3cc4f6a8efdb0e60b1136a1' }, h("div", { key: '441dd403d577b3fc62ce36578905434d8afa9393', class: "min-h-[100px] relative transition-all duration-300 overflow-hidden" }, h("div", { key: '0ffa8f30bda3deefeada3730cee9d2325f27301c' }, h(Loading, { key: 'd3f39f109b7d6972abdd0783698d846bec4f7dbe', isLoading: this.state.includes('loading') }), h("div", { key: 'f87998234935783ad922614047a7735a4411510f', class: cn('transition-all duration-700', { 'scale-0': this.state.includes('loading') || this.state === 'idle', 'opacity-0': this.state.includes('loading') }) }, h("div", { key: '884eeb64d2a41ec4e57cf86badcba19565900c5d', class: cn('text-center pt-[4px] text-[20px]', { 'text-red-600': !!this.errorMessage }) }, (_b = this.vehicleInformation) === null || _b === void 0 ? void 0 : _b.vin), ['error', 'error-loading'].includes(this.state) && (h("div", { key: 'b0eebd74f4615dd5f675e0f34d83f8e5885a9a56', class: "py-[16px]" }, h("div", { key: 'a42b69609339ef536c23a684c7e0da2dc0163547', class: " px-[16px] py-[8px] border reject-card text-[20px] rounded-[8px] w-fit mx-auto" }, this.errorMessage))), ['data', 'data-loading'].includes(this.state) && (h("div", { key: '4dc8ae93831aa45e6835aa1dba2da1fec275acfd', class: "flex mt-[12px] max-h-[70dvh] overflow-hidden rounded-[4px] flex-col border border-[#d6d8dc]" }, h("div", { key: '34ad1297b21418a1258461746d4deb2fda52d67d', class: "w-full h-[40px] flex shrink-0 justify-center text-[18px] items-center text-[#383c43] text-center bg-[#e1e3e5]" }, "Vehicle Accessories"), h("div", { key: 'aa71227b80f9cb324ea9e59ea617ee3fc32dd831', class: "h-0 overflow-auto flex-1" }, !accessories.length && h("div", { key: 'fa826cd4740662901e9ba84b35b6de408702b860', class: "h-[80px] flex items-center justify-center text-[18px]" }, "No data is available."), !!accessories.length && (h("table", { key: 'da40d63a531c6564f1c2b42c0864b70cfbbcb9f3', class: "w-full overflow-auto relative border-collapse" }, h("thead", { key: 'b516f5a0708286d43af798454b4e9dc12419c16b', class: "top-0 font-bold z-40 sticky bg-white" }, h("tr", { key: 'a8cad6f1c1a6b04e4a6f433647c54dcae311547d' }, ['Part Number', 'Description', 'Image'].map(title => (h("th", { key: title, class: "px-[10px] py-[20px] text-center whitespace-nowrap border-b border-[#d6d8dc]" }, title))))), h("tbody", { key: '8b979042a714ebd4d00c6a495d37a7c00771061a' }, accessories.map((accessory, idx) => {
            var _a;
            return (h("tr", { class: "transition-colors duration-100 hover:bg-slate-100", key: accessory.partNumber }, ['partNumber', 'description'].map(key => {
                var _a;
                return (h("td", { key: accessory.partNumber + key, class: cn('px-[10px] py-[20px] text-center whitespace-nowrap border-b border-[#d6d8dc]', {
                        '!border-none': idx === ((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.serviceHistory.length) - 1,
                    }) }, accessory[key] || '...'));
            }), h("td", { class: cn('px-[10px] py-[10px] text-center whitespace-nowrap border-b border-[#d6d8dc]', {
                    '!border-none': idx === ((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.serviceHistory.length) - 1,
                }) }, h("button", { onClick: ({ target }) => this.openImage(target, accessory.image), class: "shrink-0 relative ring-0 outline-none w-fit mx-auto [&_img]:hover:shadow-lg [&_div]:hover:!opacity-100 cursor-pointer" }, h("div", { class: "absolute flex-col justify-center gap-[4px] size-full flex items-center pointer-events-none hover:opacity-100 rounded-lg opacity-0 bg-black/40 transition-all duration-300" }, h("img", { src: Eye }), h("span", { class: "text-white" }, "Expand")), h("img", { class: "w-auto h-auto max-w-[133px] max-h-[133px] cursor-pointer shadow-sm rounded-lg transition-all duration-300", src: accessory.image })))));
        })), h("div", { key: 'c3bdaff431bde41c624126460c666b5818f7d247', onClick: () => this.closeImage(), style: { backdropFilter: this.expandedImage ? 'blur(3px)' : 'blur(0px)' }, class: cn('pointer-events-none w-[100dvw] h-[100dvh] fixed top-0 z-50 left-0 opacity-0 bg-black/40 transition-all duration-400', {
                'pointer-events-auto opacity-100 delay-200': this.expandedImage,
            }) }, h("button", { key: 'e64e829889652522fff9c4e3ba64b67f257793fa', class: "flex flex-col mt-[16px] items-center justify-center size-12 float-right mr-[16px]", onClick: () => this.closeImage() }, h("div", { key: '098418763bb6daf29076d434806890951d128ca9', class: "h-1 w-12 rounded-full rotate-45 absolute bg-white" }), h("div", { key: '729aa24bbfdc4f45656c78f0e92cb273492c78ac', class: "h-1 w-12 rounded-full -rotate-45 absolute bg-white" }))), h("img", { key: 'c2bdcb27b8972cf40a28e0fe89cbbfd4d583dd66', alt: "", id: "expanded-image", class: "fixed opacity-0 z-50 transition-all rounded-lg" })))))))))));
    }
    static get is() { return "vehicle-accessories"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["vehicle-accessories.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["vehicle-accessories.css"]
        };
    }
    static get properties() {
        return {
            "baseUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "base-url",
                "reflect": false,
                "defaultValue": "''"
            },
            "isDev": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "is-dev",
                "reflect": false,
                "defaultValue": "false"
            },
            "queryString": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "query-string",
                "reflect": false,
                "defaultValue": "''"
            },
            "loadingStateChange": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(isLoading: boolean) => void",
                    "resolved": "(isLoading: boolean) => void",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            },
            "loadedResponse": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(response: VehicleInformation) => void",
                    "resolved": "(response: VehicleInformation) => void",
                    "references": {
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            }
        };
    }
    static get states() {
        return {
            "state": {},
            "externalVin": {},
            "errorMessage": {},
            "expandedImage": {},
            "vehicleInformation": {}
        };
    }
    static get methods() {
        return {
            "setData": {
                "complexType": {
                    "signature": "(newData: VehicleInformation | string) => Promise<void>",
                    "parameters": [{
                            "name": "newData",
                            "type": "string | VehicleInformation",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        },
                        "ReturnType": {
                            "location": "global",
                            "id": "global::ReturnType"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fetchData": {
                "complexType": {
                    "signature": "(requestedVin?: string) => Promise<void>",
                    "parameters": [{
                            "name": "requestedVin",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setMockData": {
                "complexType": {
                    "signature": "(newMockData: MockJson<VehicleInformation>) => Promise<void>",
                    "parameters": [{
                            "name": "newMockData",
                            "type": "{ [key: string]: VehicleInformation; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "MockJson": {
                            "location": "import",
                            "path": "~types/components",
                            "id": "src/global/types/components.ts::MockJson"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "state",
                "methodName": "loadingListener"
            }];
    }
}
