/*!
 * Built by ShiftSoftware
 * Copyright (c)
 */
import { Host, h } from "@stencil/core";
import Loading from "../parts/Loading";
import cn from "../../global/lib/cn";
import { getVehicleInformation } from "../../global/api/vehicleInformation";
let mockData = {};
export class VehicleSpecification {
    constructor() {
        this.baseUrl = '';
        this.isDev = false;
        this.queryString = '';
        this.loadingStateChange = undefined;
        this.loadedResponse = undefined;
        this.state = 'idle';
        this.externalVin = null;
        this.errorMessage = null;
        this.vehicleInformation = undefined;
    }
    async setData(newData) {
        clearTimeout(this.networkTimeoutRef);
        if (this.abortController)
            this.abortController.abort();
        this.abortController = new AbortController();
        let scopedTimeoutRef;
        const isVinRequest = typeof newData === 'string';
        const vin = isVinRequest ? newData : newData === null || newData === void 0 ? void 0 : newData.vin;
        this.externalVin = vin;
        try {
            if (!vin || vin.trim().length === 0) {
                //this.componentHeight = '0px';
                this.state = 'idle';
                return;
            }
            if (this.state === 'data' || this.state === 'error') {
                this.state = (this.state + '-loading');
            }
            else
                this.state = 'loading';
            await new Promise(r => {
                scopedTimeoutRef = setTimeout(r, 700);
                this.networkTimeoutRef = scopedTimeoutRef;
            });
            const vehicleResponse = isVinRequest ? await getVehicleInformation(this, { scopedTimeoutRef, vin, mockData }) : newData;
            if (this.networkTimeoutRef === scopedTimeoutRef) {
                if (!vehicleResponse)
                    throw new Error('Wrong response format');
                this.vehicleInformation = vehicleResponse;
            }
            this.errorMessage = null;
            this.state = 'data';
        }
        catch (error) {
            if (error && (error === null || error === void 0 ? void 0 : error.name) === 'AbortError')
                return;
            this.state = 'error';
            this.vehicleInformation = null;
            this.errorMessage = error.message;
        }
    }
    async fetchData(requestedVin = this.externalVin) {
        await this.setData(requestedVin);
    }
    //calculateHeight(componentState: string) {
    //  if (componentState.includes('loading') && this.componentHeight === '0px') {
    //    this.componentHeight = '100px';
    //  } else if (componentState !== 'idle') {
    //    setTimeout(() => {
    //      this.componentHeight = `${this.wrapperRef.clientHeight}px`;
    //    }, 50);
    //  } else {
    //    this.componentHeight = '0px';
    //  }
    //}
    async loadingListener() {
        //this.calculateHeight(newState);
        if (this.loadingStateChange)
            this.loadingStateChange(this.state.includes('loading'));
    }
    async setMockData(newMockData) {
        mockData = newMockData;
    }
    render() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l;
        return (h(Host, { key: '48f40fc8376f3cbcb1a79d07948abf0446fe98e7' }, h("div", { key: 'ebfa06b5997131b42fd460f3946e8af00df57481', class: "min-h-[100px] relative transition-all duration-300 overflow-hidden" }, h("div", { key: '618d2c2fb8165c98fcf839598710f3d72f3919a8' }, h(Loading, { key: '0e64f3fa818bd5ffdd96e67bd82465a29046d444', isLoading: this.state.includes('loading') }), h("div", { key: '6af48b1a4c261a3d18740e970c50d6348491da04', class: cn('transition-all duration-700', { 'scale-0': this.state.includes('loading') || this.state === 'idle', 'opacity-0': this.state.includes('loading') }) }, h("div", { key: '71a7ceea3b0c54a044b48006fe9e90b5f428c430', class: cn('text-center pt-[4px] text-[20px]', { 'text-red-600': !!this.errorMessage }) }, (_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.vin), ['error', 'error-loading'].includes(this.state) && (h("div", { key: 'b84c487f3b9a4a5d79efc71f217653cbf05d4394', class: "py-4" }, h("div", { key: 'caf78747db17917b7a610c00a33db44c355ca2f2', class: " px-[16px] py-[8px] border reject-card text-[20px] rounded-[8px] w-fit mx-auto" }, this.errorMessage))), ['data', 'data-loading'].includes(this.state) && (h("div", { key: '101b8c8d793ec7e7897a25fc701b0a20ea2513a7', class: "flex mt-[12px] max-h-[70dvh] overflow-hidden rounded-[4px] flex-col border border-[#d6d8dc]" }, h("div", { key: '636763b8139e1ede34b49c72ccd22f0317677329', class: "w-full h-[40px] flex shrink-0 justify-center text-[18px] items-center text-[#383c43] text-center bg-[#e1e3e5]" }, "Vehicle Specifications"), h("div", { key: '77f0be6906e386ba0d58f8e134db4fc1b8c56c3b', class: "h-0 overflow-auto flex-1" }, !((_b = this.vehicleInformation) === null || _b === void 0 ? void 0 : _b.vehicleSpecification) && h("div", { key: 'fedc29c3c7e9b9b44454c4968570f904e7b33f38', class: "h-[80px] flex items-center justify-center text-[18px]" }, "No data is available."), !!((_c = this.vehicleInformation) === null || _c === void 0 ? void 0 : _c.vehicleSpecification) && (h("table", { key: '1319c3d9a32c344aebad43b6deb94a3693930ef6', class: "w-full overflow-auto relative border-collapse" }, h("thead", { key: 'd21b2a8739cea71d892f860a967bb7fda8b98661', class: "top-0 font-bold sticky bg-white" }, h("tr", { key: '6e571e32e63a5c32c021029f378bbe24cf7884da' }, ['Model', 'Variant', 'Katashiki', 'Model Year', 'SFX'].map(title => (h("th", { key: title, class: "px-[10px] py-[20px] text-center whitespace-nowrap border-b border-[#d6d8dc]" }, title))))), h("tbody", { key: 'ca1110af33ad5e639a2d5bc90a2c590563dece30' }, h("tr", { key: 'cbf4242a99987b00c0679a2b725f2256bb7e5e77' }, h("td", { key: '7b7def13650b744cdfa3f28ee0bd57353e200a5a', class: "px-[10px] py-[20px] text-center whitespace-nowrap" }, ((_e = (_d = this === null || this === void 0 ? void 0 : this.vehicleInformation) === null || _d === void 0 ? void 0 : _d.vehicleVariantInfo) === null || _e === void 0 ? void 0 : _e.modelCode) || '...', " ", h("br", { key: '85ce65ff0440e04c77889c98b3ef61f468d926fc', class: "my-2" }), ((_g = (_f = this === null || this === void 0 ? void 0 : this.vehicleInformation) === null || _f === void 0 ? void 0 : _f.vehicleSpecification) === null || _g === void 0 ? void 0 : _g.modelDesc) || '...'), h("td", { key: '9e85100e80d301be3ecd6cae0af580ab366271e4', class: "px-[10px] py-[20px] text-center whitespace-nowrap" }, ((_j = (_h = this === null || this === void 0 ? void 0 : this.vehicleInformation) === null || _h === void 0 ? void 0 : _h.identifiers) === null || _j === void 0 ? void 0 : _j.variant) || '...', " ", h("br", { key: 'f1487c0b01ec69a492643d84037c3590fe24b57b' }), ((_l = (_k = this === null || this === void 0 ? void 0 : this.vehicleInformation) === null || _k === void 0 ? void 0 : _k.vehicleSpecification) === null || _l === void 0 ? void 0 : _l.variantDesc) || '...'), ['identifiers.katashiki', 'vehicleVariantInfo.modelYear', 'vehicleVariantInfo.sfx'].map(infoPath => {
            var _a;
            const [place, field] = infoPath.split('.');
            const cellValue = (_a = this === null || this === void 0 ? void 0 : this.vehicleInformation) === null || _a === void 0 ? void 0 : _a[place][field].toString();
            return (h("td", { key: infoPath, class: cn('px-[10px] py-[20px] text-center whitespace-nowrap') }, cellValue.trim() ? cellValue : '...'));
        })))))))))))));
    }
    static get is() { return "vehicle-specification"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["vehicle-specification.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["vehicle-specification.css"]
        };
    }
    static get properties() {
        return {
            "baseUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "base-url",
                "reflect": false,
                "defaultValue": "''"
            },
            "isDev": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "is-dev",
                "reflect": false,
                "defaultValue": "false"
            },
            "queryString": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "query-string",
                "reflect": false,
                "defaultValue": "''"
            },
            "loadingStateChange": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(isLoading: boolean) => void",
                    "resolved": "(isLoading: boolean) => void",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            },
            "loadedResponse": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(response: VehicleInformation) => void",
                    "resolved": "(response: VehicleInformation) => void",
                    "references": {
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            }
        };
    }
    static get states() {
        return {
            "state": {},
            "externalVin": {},
            "errorMessage": {},
            "vehicleInformation": {}
        };
    }
    static get methods() {
        return {
            "setData": {
                "complexType": {
                    "signature": "(newData: VehicleInformation | string) => Promise<void>",
                    "parameters": [{
                            "name": "newData",
                            "type": "string | VehicleInformation",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        },
                        "ReturnType": {
                            "location": "global",
                            "id": "global::ReturnType"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fetchData": {
                "complexType": {
                    "signature": "(requestedVin?: string) => Promise<void>",
                    "parameters": [{
                            "name": "requestedVin",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setMockData": {
                "complexType": {
                    "signature": "(newMockData: MockJson<VehicleInformation>) => Promise<void>",
                    "parameters": [{
                            "name": "newMockData",
                            "type": "{ [key: string]: VehicleInformation; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "MockJson": {
                            "location": "import",
                            "path": "~types/components",
                            "id": "src/global/types/components.ts::MockJson"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "state",
                "methodName": "loadingListener"
            }];
    }
}
