/*!
 * Built by ShiftSoftware
 * Copyright (c)
 */
import { Host, h } from "@stencil/core";
import Loading from "./components/Loading";
import StatusCard from "./components/StatusCard";
import Loader from "~assets/loader.svg";
import CardsContainer from "./components/CardsContainer";
import SSCTable from "./components/SSCTable";
import cn from "../../global/lib/cn";
import { getVehicleInformation } from "../../global/api/vehicleInformation";
let mockData = {};
export class WarrantyDetails {
    constructor() {
        this.baseUrl = '';
        this.unauthorizedSscLookupBaseUrl = '';
        this.isDev = false;
        this.showSsc = false;
        this.queryString = '';
        this.unauthorizedSscLookupQueryString = '';
        this.recaptchaKey = '';
        this.showWarranty = false;
        this.cityId = null;
        this.cityIntegrationId = null;
        this.companyId = null;
        this.companyIntegrationId = null;
        this.companyBranchId = null;
        this.companyBranchIntegrationId = null;
        this.userId = null;
        this.brandIntegrationId = null;
        this.customerName = null;
        this.customerPhone = null;
        this.customerEmail = null;
        this.loadingStateChange = undefined;
        this.loadedResponse = undefined;
        this.state = 'idle';
        this.externalVin = null;
        this.errorMessage = null;
        this.showRecaptcha = false;
        this.unInvoicedByBrokerName = null;
        this.vehicleInformation = undefined;
        this.checkingUnauthorizedSSC = false;
        this.recaptchaRes = null;
    }
    handleSettingData(response) {
        var _a, _b, _c;
        if (response.warranty === null)
            response.warranty = {
                warrantyEndDate: '',
                warrantyStartDate: '',
                hasActiveWarranty: false,
                hasExtendedWarranty: false,
                extendedWarrantyEndDate: '',
                extendedWarrantyStartDate: '',
            };
        if (response.ssc === null)
            response.ssc = [];
        this.unInvoicedByBrokerName = null;
        if (((_a = response === null || response === void 0 ? void 0 : response.saleInformation) === null || _a === void 0 ? void 0 : _a.broker) !== null && ((_c = (_b = response === null || response === void 0 ? void 0 : response.saleInformation) === null || _b === void 0 ? void 0 : _b.broker) === null || _c === void 0 ? void 0 : _c.invoiceDate) === null)
            this.unInvoicedByBrokerName = response.saleInformation.broker.brokerName;
        this.vehicleInformation = response;
    }
    async handleInitializingRecaptcha(vin, scopedTimeoutRef) {
        var _a;
        if (((_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.isAuthorized) === false && this.showSsc && this.recaptchaKey !== '') {
            grecaptcha.reset();
            await new Promise(r => setTimeout(r, 400));
            this.recaptchaIntervalRef = setInterval(async () => {
                var _a;
                const recaptchaResponse = grecaptcha.getResponse();
                if (recaptchaResponse) {
                    clearInterval(this.recaptchaIntervalRef);
                    if (this.isDev) {
                        this.checkingUnauthorizedSSC = true;
                        this.showRecaptcha = false;
                        //this.calculateHeight(this.state);
                        await new Promise(r => setTimeout(r, 3000));
                        this.checkingUnauthorizedSSC = false;
                        const hasPendingSSC = Math.random() < 0.5 ? false : true;
                        this.recaptchaRes = {
                            hasSSC: hasPendingSSC,
                            message: hasPendingSSC ? 'This Vehicle has a Pending SSC' : 'No Pending SSC',
                        };
                        //this.calculateHeight(this.state);
                    }
                    else {
                        this.checkingUnauthorizedSSC = true;
                        this.showRecaptcha = false;
                        //this.calculateHeight(this.state);
                        const response = await fetch(`${this.unauthorizedSscLookupBaseUrl}${vin}/${(_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.sscLogId}?${this.unauthorizedSscLookupQueryString}`, {
                            signal: this.abortController.signal,
                            headers: {
                                'Ssc-Recaptcha-Token': recaptchaResponse,
                            },
                        });
                        const vinResponse = await response.json();
                        if (vinResponse && this.networkTimeoutRef === scopedTimeoutRef) {
                            this.checkingUnauthorizedSSC = false;
                            const hasPendingSSC = vinResponse.sscLookupStatus === 1;
                            this.recaptchaRes = {
                                hasSSC: hasPendingSSC,
                                message: hasPendingSSC ? 'This Vehicle has a Pending SSC' : 'No Pending SSC',
                            };
                            //this.calculateHeight(this.state);
                        }
                        else
                            throw new Error('Wrong response format');
                    }
                }
            }, 500);
            this.showRecaptcha = true;
        }
        else {
            this.showRecaptcha = false;
        }
    }
    async setData(newData) {
        this.recaptchaRes = null;
        clearTimeout(this.networkTimeoutRef);
        clearInterval(this.recaptchaIntervalRef);
        if (this.abortController)
            this.abortController.abort();
        this.abortController = new AbortController();
        let scopedTimeoutRef;
        const isVinRequest = typeof newData === 'string';
        const vin = isVinRequest ? newData : newData === null || newData === void 0 ? void 0 : newData.vin;
        this.externalVin = vin;
        try {
            if (!vin || vin.trim().length === 0) {
                //this.componentHeight = '0px';
                this.state = 'idle';
                return;
            }
            if (this.state === 'data' || this.state === 'error') {
                this.state = (this.state + '-loading');
            }
            else
                this.state = 'loading';
            await new Promise(r => {
                scopedTimeoutRef = setTimeout(r, 600);
                this.networkTimeoutRef = scopedTimeoutRef;
            });
            const vehicleResponse = isVinRequest ? await getVehicleInformation(this, { scopedTimeoutRef, vin, mockData }) : newData;
            if (this.networkTimeoutRef === scopedTimeoutRef) {
                if (!vehicleResponse)
                    throw new Error('Wrong response format');
                this.handleSettingData(vehicleResponse);
                this.handleInitializingRecaptcha(vin, scopedTimeoutRef);
            }
            this.errorMessage = null;
            this.state = 'data';
        }
        catch (error) {
            if (error && (error === null || error === void 0 ? void 0 : error.name) === 'AbortError')
                return;
            this.state = 'error';
            this.vehicleInformation = null;
            this.errorMessage = error.message;
        }
    }
    async fetchData(requestedVin = this.externalVin) {
        await this.setData(requestedVin);
    }
    async componentDidLoad() {
        if (this.recaptchaKey !== '') {
            const script = document.createElement('script');
            script.src = 'https://www.google.com/recaptcha/api.js';
            script.async = true;
            script.defer = true;
            script.onload = () => console.log('reCAPTCHA script loaded');
            document.head.appendChild(script);
        }
    }
    //calculateHeight(componentState: string) {
    //  if (componentState.includes('loading') && this.componentHeight === '0px') {
    //    this.componentHeight = '100px';
    //  } else if (componentState !== 'idle') {
    //    setTimeout(() => {
    //      this.componentHeight = `${this.wrapperRef.clientHeight}px`;
    //    }, 50);
    //  } else {
    //    this.componentHeight = '0px';
    //  }
    //}
    async setMockData(newMockData) {
        mockData = newMockData;
    }
    onShowSscChange() {
        //this.calculateHeight(this.state);
    }
    onShowWarrantyChange() {
        //this.calculateHeight(this.state);
    }
    async loadingListener() {
        //this.calculateHeight(newState);
        if (this.loadingStateChange)
            this.loadingStateChange(this.state.includes('loading'));
    }
    render() {
        var _a, _b, _c, _d, _e;
        return (h(Host, { key: 'efae5dbc3f8709e69d43297a030470a1e5bba3b1' }, h("div", { key: 'a40caab1c2244c2b4e11647f67035d19a3619e4f', class: "min-h-[100px] warranty" }, h("div", { key: '0415ecad73f86ce3572c53c6bcdf3ca939aba9ea' }, h(Loading, { key: 'f3c335c16bb7b3949d2894df1173216c6d133d13', isLoading: this.state.includes('loading') }), h("div", { key: '1ea43757d22e97104dedf1630ab13035d54616b7', class: "transition duration-700", style: { transform: this.state.includes('loading') || this.state === 'idle' ? 'scale(0)' : 'scale(1)', opacity: this.state.includes('loading') ? '0' : '1' } }, (this.showSsc || this.showWarranty) && (h("div", { key: '49af9b7fb0a2bd63fba8dc6f3d86910b1dfef1dd', style: { color: !!this.errorMessage ? 'red' : 'black' }, class: "warranty-vin" }, (_a = this.vehicleInformation) === null || _a === void 0 ? void 0 : _a.vin)), ['error', 'error-loading'].includes(this.state) && (h("div", { key: '436a395e98ee8ecd623795ceff7bc67e26f3dcf7', class: "py-4" }, h(StatusCard, { key: '4aa98f1f417bee1ffecbfff4b9448cfc3ac6a937', desc: this.errorMessage, className: "mx-auto reject-card max-w-500" }), ' ')), this.showWarranty && ['data', 'data-loading'].includes(this.state) && (h(CardsContainer, { key: '77c6780a1f1fa811c5151dde3eb04adb62f56b67', isAuthorized: (_b = this.vehicleInformation) === null || _b === void 0 ? void 0 : _b.isAuthorized, unInvoicedByBrokerName: this.unInvoicedByBrokerName, warranty: (_c = this.vehicleInformation) === null || _c === void 0 ? void 0 : _c.warranty })), h("div", { key: '97787b3a8fd8b0e4557e698a67e5ba82e1b21655', style: Object.assign({}, (this.showRecaptcha ? { height: 'auto', padding: '16px 16px 0px 16px' } : { height: '0px' })), class: "recaptcha-container" }, h("slot", { key: '49d91019bd3fbfa33087d70cb835c26800ea65e9' })), ['data', 'data-loading'].includes(this.state) && this.recaptchaRes && (h("div", { key: '81ae9c6485e00767093ee1055686c59fb28ffbbf', class: cn('recaptcha-response', !this.recaptchaRes.hasSSC ? 'success-card' : 'reject-card ') }, this.recaptchaRes.message)), this.checkingUnauthorizedSSC && (h("div", { key: '18748b3d109020fa5b8490a15dc400435adb86b0', class: "loading-spinner", style: { marginTop: '20px', flexDirection: 'column' } }, h("div", { key: '3da07489cf30aa92e7b2811774c37f2d499272d3' }, h("strong", { key: '239f87dc57db5b806957eb239f0bddaf793937b3' }, "Checking TMC")), h("img", { key: '506b1c84225e141f9eb7e652821914eb5f36b78b', class: "spin", src: Loader }))), this.showSsc && ['data', 'data-loading'].includes(this.state) && ((_d = this.vehicleInformation) === null || _d === void 0 ? void 0 : _d.ssc) !== null && !!((_e = this.vehicleInformation) === null || _e === void 0 ? void 0 : _e.ssc.length) && (h(SSCTable, { key: '83ed2284fdedc1a91eb7db1afe4d25321069cf06', ssc: this.vehicleInformation.ssc })))))));
    }
    static get is() { return "warranty-details"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["warranty-details.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["warranty-details.css"]
        };
    }
    static get properties() {
        return {
            "baseUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "base-url",
                "reflect": false,
                "defaultValue": "''"
            },
            "unauthorizedSscLookupBaseUrl": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "unauthorized-ssc-lookup-base-url",
                "reflect": false,
                "defaultValue": "''"
            },
            "isDev": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "is-dev",
                "reflect": false,
                "defaultValue": "false"
            },
            "showSsc": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "show-ssc",
                "reflect": false,
                "defaultValue": "false"
            },
            "queryString": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "query-string",
                "reflect": false,
                "defaultValue": "''"
            },
            "unauthorizedSscLookupQueryString": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "unauthorized-ssc-lookup-query-string",
                "reflect": false,
                "defaultValue": "''"
            },
            "recaptchaKey": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "recaptcha-key",
                "reflect": false,
                "defaultValue": "''"
            },
            "showWarranty": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "show-warranty",
                "reflect": false,
                "defaultValue": "false"
            },
            "cityId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "city-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "cityIntegrationId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "city-integration-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "companyId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "company-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "companyIntegrationId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "company-integration-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "companyBranchId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "company-branch-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "companyBranchIntegrationId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "company-branch-integration-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "userId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "user-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "brandIntegrationId": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "brand-integration-id",
                "reflect": false,
                "defaultValue": "null"
            },
            "customerName": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "customer-name",
                "reflect": false,
                "defaultValue": "null"
            },
            "customerPhone": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "customer-phone",
                "reflect": false,
                "defaultValue": "null"
            },
            "customerEmail": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "attribute": "customer-email",
                "reflect": false,
                "defaultValue": "null"
            },
            "loadingStateChange": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(isLoading: boolean) => void",
                    "resolved": "(isLoading: boolean) => void",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            },
            "loadedResponse": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "(response: VehicleInformation) => void",
                    "resolved": "(response: VehicleInformation) => void",
                    "references": {
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                }
            }
        };
    }
    static get states() {
        return {
            "state": {},
            "externalVin": {},
            "errorMessage": {},
            "showRecaptcha": {},
            "unInvoicedByBrokerName": {},
            "vehicleInformation": {},
            "checkingUnauthorizedSSC": {},
            "recaptchaRes": {}
        };
    }
    static get methods() {
        return {
            "setData": {
                "complexType": {
                    "signature": "(newData: VehicleInformation | string) => Promise<void>",
                    "parameters": [{
                            "name": "newData",
                            "type": "string | VehicleInformation",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        },
                        "ReturnType": {
                            "location": "global",
                            "id": "global::ReturnType"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fetchData": {
                "complexType": {
                    "signature": "(requestedVin?: string) => Promise<void>",
                    "parameters": [{
                            "name": "requestedVin",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "setMockData": {
                "complexType": {
                    "signature": "(newMockData: MockJson<VehicleInformation>) => Promise<void>",
                    "parameters": [{
                            "name": "newMockData",
                            "type": "{ [key: string]: VehicleInformation; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "MockJson": {
                            "location": "import",
                            "path": "~types/components",
                            "id": "src/global/types/components.ts::MockJson"
                        },
                        "VehicleInformation": {
                            "location": "import",
                            "path": "~types/vehicle-information",
                            "id": "src/global/types/vehicle-information.ts::VehicleInformation"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "showSsc",
                "methodName": "onShowSscChange"
            }, {
                "propName": "showWarranty",
                "methodName": "onShowWarrantyChange"
            }, {
                "propName": "state",
                "methodName": "loadingListener"
            }];
    }
}
