/*!
 * Built by ShiftSoftware
 * Copyright (c)
 */
export class FormHook {
    constructor(context, schemaObject, formStateOptions) {
        this.isSubmitted = false;
        this.validationType = 'onSubmit';
        this.subscribedFields = {};
        this.formErrors = {};
        this.getFormErrors = () => this.formErrors;
        this.getValues = () => {
            const form = this.context.el.shadowRoot.querySelector('form');
            const formData = new FormData(form);
            const formObject = Object.fromEntries(formData.entries());
            return formObject;
        };
        this.focusFirstInput = (errorFields) => {
            if (errorFields.length) {
                const domElements = errorFields.map(field => this.context.el.shadowRoot.querySelector(`input[name="${field.name}"]`)).filter(dom => dom);
                const sortedDomElements = domElements.sort((a, b) => {
                    if (a.compareDocumentPosition(b) & Node.DOCUMENT_POSITION_FOLLOWING)
                        return -1; // a comes before b
                    if (a.compareDocumentPosition(b) & Node.DOCUMENT_POSITION_PRECEDING)
                        return 1; // b comes before a
                    return 0; // They are the same
                });
                if (sortedDomElements[0])
                    sortedDomElements[0].focus();
            }
        };
        this.onSubmit = (formEvent) => {
            formEvent.preventDefault();
            (async () => {
                try {
                    this.isSubmitted = true;
                    this.context.isLoading = true;
                    this.signal({ isError: false });
                    const formObject = this.getValues();
                    const values = await this.schemaObject.validate(formObject, { abortEarly: false, strict: true });
                    await this.context.formSubmit(values);
                }
                catch (error) {
                    if (error.name === 'ValidationError') {
                        this.formErrors = {};
                        const errorFields = [];
                        error.inner.forEach((element) => {
                            if (element.path) {
                                this.formErrors[element.path] = element.message;
                                if (!errorFields.find(field => field.name === element.path))
                                    errorFields.push({
                                        isError: true,
                                        name: element.path,
                                        errorMessage: element.message,
                                    });
                            }
                        });
                        this.signal(errorFields);
                        this.focusFirstInput(errorFields);
                    }
                    else
                        console.error('Unexpected Error:', error);
                }
                finally {
                    this.context.isLoading = false;
                }
            })();
        };
        this.newController = (name, fieldType) => {
            if (fieldType === 'text')
                this.subscribedFields[name] = {
                    name,
                    isError: false,
                    disabled: false,
                    errorMessage: '',
                    onInput: (event) => {
                        const value = event.target.value;
                        this.onChanges(name, value);
                    },
                };
            return this.subscribedFields[name];
        };
        this.signal = (partialSignal) => {
            if (Array.isArray(partialSignal)) {
                partialSignal.forEach(field => {
                    if (this.subscribedFields[field.name])
                        Object.assign(this.subscribedFields[field.name], field);
                });
            }
            else {
                Object.values(this.subscribedFields).forEach(field => Object.assign(field, partialSignal));
            }
        };
        this.onChanges = async (name, value) => {
            if (!this.isSubmitted && this.validationType !== 'always')
                return;
            const wasError = this.subscribedFields[name].isError;
            try {
                // @ts-ignore
                this.schemaObject.fields[name].validateSync(value);
                this.signal([{ name, isError: false }]);
                if (wasError !== false)
                    this.context.renderControl = {};
            }
            catch (error) {
                if (error.message) {
                    this.signal([{ name, isError: true, errorMessage: error.message }]);
                    this.context.renderControl = {};
                }
            }
        };
        this.context = context;
        this.schemaObject = schemaObject;
        this.formController = { onSubmit: this.onSubmit };
        if (formStateOptions === null || formStateOptions === void 0 ? void 0 : formStateOptions.validationType)
            this.validationType = formStateOptions.validationType;
    }
}
